/* 数据字典
 * @Author: Li Hanlin
 * @Date: 2022-11-24 11:16:02
 * @Last Modified by: Li Hanlin
 * @Last Modified time: 2022-11-30 14:02:16
 */
import * as React from 'react';
import { useState, useMemo, useRef } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import getcolumns from './columns';
import { doFetch } from '@/utils/doFetch';
import { message } from 'antd';

function Type(props) {
  const actionRef = useRef(),
    formRef = useRef();
  const [drawer, setDrawer] = useState({
    visible: false,
  });

  const urlParams = {
    save: '/base/sysEtcData/save',
    remove: '/base/sysEtcData/delete',
    list: '/base/sysData/query/tree',
    detail: '/base/sysEtcData/detail',
  };

  const detail = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          type: 'link',
          onClick: () => {
            setDrawer((s) => ({
              ...s,
              visible: true,
              item: row,
              title: '详情',
              val: 'detail',
              title: row.userName + '的详细信息',
            }));
          },
        }}
      >
        详情
      </PremButton>
    );
  };

  const edit = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          disabled: row?.dataType == 1 ? true : false,
          onClick: () => {
            console.log(row);
            setDrawer((s) => ({
              ...s,
              visible: true,
              item: {
                ...row,
                dataType: row?.dataTypeName,
                dataName: row?.title,
              },
              title: '编辑',
              val: 'edit',
              onFinish: async (vals) => {
                console.log(vals);
                let params = {
                  ...vals,
                  id: row.key,
                  parentId: row.parentKey,
                };
                console.log(params);
                delete params.title;
                delete params.dataType;
                let res = await doFetch({
                  url: urlParams.save,
                  params,
                });
                if (res.code === '0000') {
                  message.success('编辑成功！');
                  setDrawer((s) => ({
                    ...s,
                    visible: false,
                  }));
                  actionRef.current.reload();
                }
              },
            }));
          },
        }}
      >
        编辑
      </PremButton>
    );
  };

  const addChild = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          // disabled: row?.dataType == 1 ? true : false,
          size: 'small',
          onClick: () => {
            setDrawer((s) => ({
              ...s,
              visible: true,
              detailpath: null,
              item: {
                dataType: '自定义',
              },
              title: '新增数据',
              val: 'addChild',
              onFinish: async (vals) => {
                console.log(vals);
                let params = {
                  ...vals,
                  parentId: row.key,
                };
                delete params.dataType;
                let res = await doFetch({
                  url: urlParams.save,
                  params,
                });
                if (res.code === '0000') {
                  message.success('新增数据成功！');
                  setDrawer((s) => ({
                    ...s,
                    visible: false,
                  }));
                  actionRef.current.reload();
                }
              },
            }));
          },
        }}
      >
        新增数据
      </PremButton>
    );
  };

  const remove = (text, row, _, action) => {
    return (
      <PremButton
        pop={{
          title: '是否删除该字典项?',
          disabled: row?.dataType == 1 ? true : false,
          okText: '确认',
          cancelText: '取消',
          onConfirm: async () => {
            let res = await doFetch({ url: urlParams.remove, params: { id: row.key } });
            if (res.code === '0000') {
              message.success('删除成功！');
              setDrawer((s) => ({
                ...s,
                visible: false,
              }));
              actionRef.current.reload();
            }
          },
        }}
        btn={{
          size: 'small',
          disabled: row?.dataType == 1 ? true : false,
          type: 'danger',
        }}
      >
        删除
      </PremButton>
    );
  };

  const columns = useMemo(() => {
    let defcolumn = getcolumns(setDrawer);

    return defcolumn.concat({
      title: '操作',
      valueType: 'option',
      width: 150,
      render: (text, row, _, action) => {
        if (row?.parentKey == '0') {
          return [addChild(text, row, _, action)];
        } else {
          return [edit(text, row, _, action), remove(text, row, _, action)];
        }
      },
    });
  }, [drawer.val]);

  return (
    <div style={{ position: 'relative' }}>
      <AutoTable
        pagetitle={<h3 className="page-title">数据字典</h3>}
        columns={columns}
        path={urlParams.list}
        actionRef={actionRef}
        resizeable={false}
        addconfig={{
          // access: 'sysDepartment_save',
          btn: {
            disabled: false,
            type: 'primary',
            onClick: () => {
              setDrawer((s) => ({
                ...s,
                visible: true,
                item: {
                  departmentTypeName: '公司类型',
                },
                title: '新增',
                detailpath: null,
                val: 'add',
                onFinish: async (vals) => {
                  let params = {
                    ...vals,
                    departmentType: 0,
                  };
                  let res = await doFetch({
                    url: urlParams.save,
                    params,
                  });
                  if (res.code === '0000') {
                    message.success('新增成功！');
                    setDrawer((s) => ({
                      ...s,
                      visible: false,
                    }));
                    actionRef.current.reload();
                  }
                },
              }));
            },
          },
        }}
        pagination={false}
      />

      <DrawerPro
        fields={columns}
        defaultFormValue={drawer?.item ?? {}}
        formRef={formRef}
        placement="right"
        onClose={() => {
          setDrawer((s) => ({
            ...s,
            visible: false,
          }));
        }}
        {...drawer}
      />
    </div>
  );
}

export default Type;
